@@ -16,6 +16,7 @@ from gac.providers import (
     call_ollama_api,
     call_openai_api,
     call_openrouter_api,
+    call_zai_api,
 )
 
 logger = logging.getLogger(__name__)
@@ -67,6 +68,7 @@ def generate_commit_message(
         "cerebras": call_cerebras_api,
         "ollama": call_ollama_api,
         "openrouter": call_openrouter_api,
+        "zai": call_zai_api,
     }
 
     # Generate the commit message using centralized retry logic
@@ -81,6 +83,9 @@ def generate_commit_message(
             max_retries=max_retries,
             quiet=quiet,
         )
+    except AIError:
+        # Re-raise AIError exceptions as-is to preserve error classification
+        raise
     except Exception as e:
         logger.error(f"Failed to generate commit message: {e}")
         raise AIError.model_error(f"Failed to generate commit message: {e}") from e
