@@ -24,15 +24,16 @@ def init() -> None:
         ("Cerebras", "qwen-3-coder-480b"),
         ("Groq", "meta-llama/llama-4-maverick-17b-128e-instruct"),
         ("Ollama", "gemma3"),
-        ("OpenRouter", "openrouter/auto"),
         ("OpenAI", "gpt-4.1-mini"),
+        ("OpenRouter", "openrouter/auto"),
+        ("Z.AI", "glm-4.6"),
     ]
     provider_names = [p[0] for p in providers]
     provider = questionary.select("Select your provider:", choices=provider_names).ask()
     if not provider:
         click.echo("Provider selection cancelled. Exiting.")
         return
-    provider_key = provider.lower()
+    provider_key = provider.lower().replace(".", "")
     model_suggestion = dict(providers)[provider]
     model = questionary.text(f"Enter the model (default: {model_suggestion}):", default=model_suggestion).ask()
     model_to_save = model.strip() if model.strip() else model_suggestion
@@ -44,4 +45,14 @@ def init() -> None:
         set_key(str(GAC_ENV_PATH), f"{provider_key.upper()}_API_KEY", api_key)
         click.echo(f"Set {provider_key.upper()}_API_KEY (hidden)")
 
+    # Ask about ZAI coding plan if Z.AI provider was selected
+    if provider_key == "zai":
+        use_coding_api = questionary.confirm(
+            "Are you using a Z.AI coding plan? (uses different API endpoint)",
+            default=False,
+        ).ask()
+        if use_coding_api:
+            set_key(str(GAC_ENV_PATH), "GAC_ZAI_USE_CODING_PLAN", "true")
+            click.echo("Set GAC_ZAI_USE_CODING_PLAN=true")
+
     click.echo(f"\ngac environment setup complete. You can edit {GAC_ENV_PATH} to update values later.")
