@@ -23,10 +23,12 @@ from gac.git import (
 )
 from gac.preprocess import preprocess_diff
 from gac.prompt import build_prompt, clean_commit_message
+from gac.security import get_affected_files, scan_staged_diff
 
 logger = logging.getLogger(__name__)
 
 config = load_config()
+console = Console()  # Initialize console globally to prevent undefined access
 
 
 def main(
@@ -41,6 +43,7 @@ def main(
     quiet: bool = False,
     dry_run: bool = False,
     no_verify: bool = False,
+    skip_secret_scan: bool = False,
 ) -> None:
     """Main application logic for gac."""
     try:
@@ -72,7 +75,6 @@ def main(
     # Check for staged files
     staged_files = get_staged_files(existing_only=False)
     if not staged_files:
-        console = Console()
         console.print(
             "[yellow]No staged changes found. Stage your changes with git add first or use --add-all.[/yellow]"
         )
@@ -81,7 +83,6 @@ def main(
     # Run pre-commit hooks before doing expensive operations
     if not no_verify and not dry_run:
         if not run_pre_commit_hooks():
-            console = Console()
             console.print("[red]Pre-commit hooks failed. Please fix the issues and try again.[/red]")
             console.print("[yellow]You can use --no-verify to skip pre-commit hooks.[/yellow]")
             sys.exit(1)
@@ -90,6 +91,72 @@ def main(
     diff = run_git_command(["diff", "--staged"])
     diff_stat = " " + run_git_command(["diff", "--stat", "--cached"])
 
+    # Security scan for secrets
+    if not skip_secret_scan:
+        logger.info("Scanning staged changes for potential secrets...")
+        secrets = scan_staged_diff(diff)
+        if secrets:
+            if not quiet:
+                console.print("\n[bold red]⚠️  SECURITY WARNING: Potential secrets detected![/bold red]")
+                console.print("[red]The following sensitive information was found in your staged changes:[/red]\n")
+
+            for secret in secrets:
+                location = f"{secret.file_path}:{secret.line_number}" if secret.line_number else secret.file_path
+                if not quiet:
+                    console.print(f"  • [yellow]{secret.secret_type}[/yellow] in [cyan]{location}[/cyan]")
+                    console.print(f"    Match: [dim]{secret.matched_text}[/dim]\n")
+
+            if not quiet:
+                console.print("\n[bold]Options:[/bold]")
+                console.print("  \\[a] Abort commit (recommended)")
+                console.print("  \\[c] [yellow]Continue anyway[/yellow] (not recommended)")
+                console.print("  \\[r] Remove affected file(s) and continue")
+
+            try:
+                choice = (
+                    click.prompt(
+                        "\nChoose an option",
+                        type=click.Choice(["a", "c", "r"], case_sensitive=False),
+                        default="a",
+                        show_choices=True,
+                        show_default=True,
+                    )
+                    .strip()
+                    .lower()
+                )
+            except (EOFError, KeyboardInterrupt):
+                console.print("\n[red]Aborted by user.[/red]")
+                sys.exit(0)
+
+            if choice == "a":
+                console.print("[yellow]Commit aborted.[/yellow]")
+                sys.exit(0)
+            elif choice == "c":
+                console.print("[bold yellow]⚠️  Continuing with potential secrets in commit...[/bold yellow]")
+                logger.warning("User chose to continue despite detected secrets")
+            elif choice == "r":
+                affected_files = get_affected_files(secrets)
+                for file_path in affected_files:
+                    try:
+                        run_git_command(["reset", "HEAD", file_path])
+                        console.print(f"[green]Unstaged: {file_path}[/green]")
+                    except GitError as e:
+                        console.print(f"[red]Failed to unstage {file_path}: {e}[/red]")
+
+                # Check if there are still staged files
+                remaining_staged = get_staged_files(existing_only=False)
+                if not remaining_staged:
+                    console.print("[yellow]No files remain staged. Commit aborted.[/yellow]")
+                    sys.exit(0)
+
+                console.print(f"[green]Continuing with {len(remaining_staged)} staged file(s)...[/green]")
+                # Refresh all git state variables after removing files
+                status = run_git_command(["status"])
+                diff = run_git_command(["diff", "--staged"])
+                diff_stat = " " + run_git_command(["diff", "--stat", "--cached"])
+        else:
+            logger.info("No secrets detected in staged changes")
+
     # Preprocess the diff before passing to build_prompt
     logger.debug(f"Preprocessing diff ({len(diff)} characters)")
     model_id = model or config["model"]
@@ -106,7 +173,6 @@ def main(
     )
 
     if show_prompt:
-        console = Console()
         # Show both system and user prompts
         full_prompt = f"SYSTEM PROMPT:\n{system_prompt}\n\nUSER PROMPT:\n{user_prompt}"
         console.print(
@@ -123,7 +189,6 @@ def main(
 
         warning_limit = config.get("warning_limit_tokens", EnvDefaults.WARNING_LIMIT_TOKENS)
         if warning_limit and prompt_tokens > warning_limit:
-            console = Console()
             console.print(
                 f"[yellow]⚠️  WARNING: Prompt contains {prompt_tokens} tokens, which exceeds the warning limit of "
                 f"{warning_limit} tokens.[/yellow]"
@@ -147,8 +212,6 @@ def main(
         logger.info("Generated commit message:")
         logger.info(commit_message)
 
-        console = Console()
-
         # Reroll loop
         while True:
             console.print("[bold green]Generated commit message:[/bold green]")
@@ -250,7 +313,6 @@ def main(
             console.print("[green]Commit created successfully[/green]")
     except AIError as e:
         logger.error(str(e))
-        console = Console()
         console.print(f"[red]Failed to generate commit message: {str(e)}[/red]")
         sys.exit(1)
 
