@@ -6,6 +6,7 @@ from .groq import call_groq_api
 from .ollama import call_ollama_api
 from .openai import call_openai_api
 from .openrouter import call_openrouter_api
+from .zai import call_zai_api
 
 __all__ = [
     "call_anthropic_api",
@@ -14,4 +15,5 @@ __all__ = [
     "call_ollama_api",
     "call_openai_api",
     "call_openrouter_api",
+    "call_zai_api",
 ]
